@@ -1,4 +1,4 @@
-from cleo import Application
+from cleo.application import Application
 
 from sdoc.command.SDoc1Command import SDoc1Command
 from sdoc.command.SDoc2Command import SDoc2Command
@@ -16,21 +16,10 @@ class SDocApplication(Application):
         """
         Object constructor.
         """
-        Application.__init__(self, 'SDocApplication', '0.0.11')
-
-    # ------------------------------------------------------------------------------------------------------------------
-    def get_default_commands(self):
-        """
-        Returns the default commands of this application.
-
-        :rtype: list[cleo.Command]
-        """
-        commands = Application.get_default_commands(self)
+        Application.__init__(self, 'SDoc', '1.0.0')
 
         self.add(SDocCommand())
         self.add(SDoc1Command())
         self.add(SDoc2Command())
 
-        return commands
-
 # ----------------------------------------------------------------------------------------------------------------------
